#
# Configure paths and flags for the SEvMgr library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the SEVMGR library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * SEVMGR_VERSION
#  * SEVMGR_CFLAGS
#  * SEVMGR_LIBS
#  * SEVMGR_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_SEVMGR],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(sevmgr,
	[ --with-sevmgr=PFX Prefix where SEvMgr is installed (optional) ],
	    sevmgr_dir="$withval",
	    sevmgr_dir="")

  if test "x${SEVMGR_CONFIG+set}" != xset ; then
     if test "x$sevmgr_dir" != x ; then
         SEVMGR_CONFIG="$sevmgr_dir/bin/sevmgr-config"
     fi
  fi

  AC_PATH_PROG(SEVMGR_CONFIG, sevmgr-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: SEvMgr needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the SEvMgr will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: SEvMgr needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The SEvMgr may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: SEvMgr needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The SEvMgr may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: SEvMgr needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The SEvMgr may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## SEvMgr version
  min_sevmgr_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for SEvMgr - version >= $min_sevmgr_version)
  no_sevmgr=""
  if test "${SEVMGR_CONFIG}" = "no" ; then
     no_sevmgr=yes
     AC_MSG_RESULT([no])
  else
     SEVMGR_VERSION=`${SEVMGR_CONFIG} --version`
     SEVMGR_CFLAGS=`${SEVMGR_CONFIG} --cflags`
     SEVMGR_CFLAGS="${BOOST_CFLAGS} ${SEVMGR_CFLAGS}"
     SEVMGR_LIBS=`${SEVMGR_CONFIG} --libs`
     SEVMGR_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${SEVMGR_LIBS}"
     SEVMGR_SAMPLE_DIR=`${SEVMGR_CONFIG} --sampledir`

     AC_SUBST([SEVMGR_VERSION])
     AC_SUBST([SEVMGR_CFLAGS])
     AC_SUBST([SEVMGR_LIBS])
     AC_SUBST([SEVMGR_SAMPLE_DIR])

    sevmgr_major_version=`echo ${SEVMGR_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${sevmgr_major_version}" = "x" ; then
       sevmgr_major_version=0
    fi

    sevmgr_minor_version=`echo ${SEVMGR_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${sevmgr_minor_version}" = "x" ; then
       sevmgr_minor_version=0
    fi

    sevmgr_micro_version=`echo ${SEVMGR_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${sevmgr_micro_version}" = "x" ; then
       sevmgr_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${SEVMGR_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${SEVMGR_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <sevmgr/SEVMGR_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${SEVMGR_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple SEvMgr example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
